@@ -60,6 +60,13 @@ def fetch_secret_api_token(username, password):
                 form_data=dict(username=username, password=password))
     return res
 
+def update_secret_api_token_name(api_key_uuid, name, token):
+    res = lab_request(path=f"/api-key/{api_key_uuid}", 
+                request_type="PUT", 
+                token=token,
+                body_args=dict(name=name))
+    return res
+
 def fetch_minimum_python_version():
     res = lab_request(path="/minimum-supported-python-version", 
                 request_type="GET")
